@@ -307,6 +307,9 @@ class PlacementController:
         'charm_name-1', etc"""
         self.bundle.add_new_service(charm_name, charm_dict, service_name)
 
+    def set_option(self, service_name, opname, value):
+        self.bundle.set_option(service_name, opname, value)
+
     def update_from_bundle(self):
         self.add_bundle_machines(self.bundle.machines)
         self.add_bundle_assignments(self.bundle.assignments)
